#include "qtguiapplication1.h"
#include <QGridLayout>
#include <QGroupBox>
#include <QLabel>
#include <QCheckBox>
#include <QPushButton>
#include <QComboBox> 
#include <QButtonGroup> 
#include <QRadioButton>
#include <QStyleFactory>
#include <QLineEdit>

QtGuiApplication1::QtGuiApplication1( QWidget * parent )
	: QMainWindow( parent )
{
	ui.setupUi( this );

	setWindowTitle( "Printer Preview" );

	CreateWidgets();
}

void QtGuiApplication1::CreateWidgets()
{
	// see the list of all available layouts in Qt
	// https://doc.qt.io/qt-5/layout.html

	// central frame layout
	QGridLayout * main = new QGridLayout();
	ui.centralWidget->setLayout( main );

	// printer settings frame
	{
		// create frame (container)
		QGroupBox * printer = new QGroupBox( this );
		printer->setTitle( "Printer settings:" );
		// and put it inside the main layout
		main->addWidget( printer, 0, 0, Qt::AlignLeft | Qt::AlignTop );

		// create all the widgets you need here
		// see the list of all basic widgets in Qt
		// https://doc.qt.io/qt-5/widget-classes.html#basic-widget-classes

		QLabel * lbl1 = new QLabel( this );
		lbl1->setText( "Printer:" );

		QLabel * lbl2 = new QLabel( this );
		lbl2->setText( "Paper:" );

		QLabel * lbl3 = new QLabel( this );
		lbl3->setText( "A4, 600 DPI" );
		lbl3->setFrameStyle( QFrame::Panel | QFrame::Sunken );
		lbl3->setAlignment( Qt::AlignCenter );
		lbl3->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );

		QCheckBox * chbUseDefault = new QCheckBox( this );
		chbUseDefault->setText( "Always use system default printer at dialog start" );

		QCheckBox * chbAutoRotate = new QCheckBox( this );
		chbAutoRotate->setText( "Auto-rotate" );

		QPushButton * btnSetup = new QPushButton( "Printer setup" );
		btnSetup->setMaximumWidth( 100 );

		QComboBox * cmbPrinters = new QComboBox( this );
		//cmbPrinters->setStyleSheet( "QComboBox{ background: white; }" );
		cmbPrinters->addItems( QStringList( { "Microsoft Print to PDF", "HP Laser Jet" } ) );
		//QStyle *s = cmbPrinters->style();
		//s->SC_ComboBoxEditField = 1;
		//QStringList keys = QStyleFactory::keys();
		cmbPrinters->setEditable( true );
		//cmbPrinters->setStyle( QStyleFactory::create( keys[0]) );

		QButtonGroup * rbgOrientation = new QButtonGroup( this );
		QRadioButton * rbtPortrait = new QRadioButton( "Portrait" );
		rbtPortrait->setChecked( true );
		rbgOrientation->addButton( rbtPortrait );
		QRadioButton * rbtLandscape = new QRadioButton( "Landscape" );
		rbgOrientation->addButton( rbtLandscape );				

		QLineEdit * edtLine = new QLineEdit( this ); // don't forget to include <QLineEdit>
		edtLine->setText( "ScanImage" );
		edtLine->setEnabled( false );

		QFrame * frmButtons = new QFrame( this );		

		QPushButton * btnOk = new QPushButton( this );
		btnOk->setText( "OK" );		
		// see https://doc.qt.io/qt-5/stylesheet-examples.html
		// for pre-defined color names see https://doc.qt.io/qt-5/qcolorconstants.html
		btnOk->setStyleSheet( 
			"QPushButton{border:4px solid dodgerblue;border-radius:6px;background-color: qlineargradient(x1:0, y1:0, x2:0, y2:1, stop: 0 #f6f7fa, stop: 1 #dadbde);min-width: 70px;}"
			"QPushButton:hover{ border:4px solid deepskyblue;}"
			"QPushButton:pressed{border:4px solid lightskyblue;}");
		btnOk->setMinimumWidth( 80 );

		QPushButton * btnCancel = new QPushButton( this );
		btnCancel->setText( "Cancel" );
		btnCancel->setMinimumWidth( 80 );

		// create and set the layout
		QGridLayout * layout = new QGridLayout( this );
		printer->setLayout( layout );

		// add individual widgets into the layout of the current frame
		layout->addWidget( lbl1, 0, 0, Qt::AlignLeft );
		layout->addWidget( chbUseDefault, 0, 2, 1, 2, Qt::AlignLeft );

		layout->addWidget( cmbPrinters, 1, 0, 1, 4 );

		layout->addWidget( rbtPortrait, 2, 0, Qt::AlignLeft );
		layout->addWidget( lbl2, 2, 1, Qt::AlignRight );
		layout->addWidget( chbAutoRotate, 2, 2, Qt::AlignLeft );

		layout->addWidget( rbtLandscape, 3, 0, Qt::AlignLeft );
		layout->addWidget( lbl3, 3, 1, 1, 2 );
		layout->addWidget( btnSetup, 3, 3 );

		layout->addWidget( edtLine, 4, 0, 1, 4 );

		layout->addWidget( frmButtons, 5, 0, 1, 4, Qt::AlignRight );

		// create and set the layout for buttons
		QHBoxLayout * layoutButtons = new QHBoxLayout( this );
		layoutButtons->setSpacing( 8 );
		layoutButtons->setMargin( 0 );
		frmButtons->setLayout( layoutButtons );

		layoutButtons->addWidget( btnOk );
		layoutButtons->addWidget( btnCancel);
	}

	{
		// TODO add next frame
	}
}
